@@ -8,9 +8,11 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.aws_iam
 import aws_cdk.core
+import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-codeguruprofiler", "1.41.0", __name__[0:-6], "aws-codeguruprofiler@1.41.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-codeguruprofiler", "1.42.1", __name__[0:-6], "aws-codeguruprofiler@1.42.1.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
